#app,body,html{height:100%;width:100%}.title-container[data-v-b6bc38e0]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.title-button[data-v-b6bc38e0]{margin-left:1rem}.feed-title[data-v-b6bc38e0]{color:#000}.list-title[data-v-b6bc38e0]{margin-top:1.5rem}table[data-v-b6bc38e0]{width:100%}.keyword-container[data-v-2ba4fb22]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.add-button[data-v-2ba4fb22]{margin-left:1rem;color:#000}.delete-button[data-v-2ba4fb22]{margin-left:.5rem;color:#000}table[data-v-8107c4d4]{width:100%}.title-container[data-v-8107c4d4]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.title-button[data-v-8107c4d4]{margin-left:1rem}.list-title[data-v-8107c4d4]{margin-top:1.5rem}
/*# sourceMappingURL=app.d6c17de93bdc942fb8af9030709fbed8.css.map */