<!DOCTYPE html><html><head><meta charset=utf-8><meta name=viewport content="width=device-width,initial-scale=1"><title>RSS Transmission WEBUI</title><link href=https://cdn.bootcss.com/bulma/0.6.2/css/bulma.min.css rel=stylesheet><link href=https://cdn.bootcss.com/font-awesome/4.7.0/css/font-awesome.min.css rel=stylesheet><link href=/static/css/app.d6c17de93bdc942fb8af9030709fbed8.css rel=stylesheet></head><body><div id=app></div><script type=text/javascript src=/static/js/manifest.c480bfd993d7b7d38f1c.js></script><script type=text/javascript src=/static/js/vendor.b2eb89e18d88c6a43cb2.js></script><script type=text/javascript src=/static/js/app.da8b9bc6b8567fad689b.js></script></body></html>